==> jetty9_9.4.15.orig.tar.xz: jetty9-9.4.15/jetty-maven-plugin/src/it/javax-annotation-api/src/main/java/test/App.java <==
//
//  ========================================================================
//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
//  ------------------------------------------------------------------------
//  All rights reserved. This program and the accompanying materials
//  are made available under the terms of the Eclipse Public License v1.0
//  and Apache License v2.0 which accompanies this distribution.
//
//      The Eclipse Public License is available at
//      http://www.eclipse.org/legal/epl-v10.html
//
//      The Apache License v2.0 is available at
//      http://www.opensource.org/licenses/apache2.0.php
//
//  You may elect to redistribute this code under either of these licenses.
//  ========================================================================
//

package test;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.builder.SpringApplicationBuilder;
import org.springframework.boot.web.servlet.support.SpringBootServletInitializer;
import org.springframework.context.annotation.Bean;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.io.InputStream;
import java.util.Properties;

/**
 * Hello world!
 *
 */
public class App extends SpringBootServletInitializer {

    private Logger logger = LoggerFactory.getLogger( getClass() );

    @Resource(name="my.properties")
    private Properties somePropertyFile;

    @Override
    protected SpringApplicationBuilder configure(SpringApplicationBuilder builder ) {
        return builder.sources( App.class );
    }

    @PostConstruct
    public void done(){
        logger.info( "all good guys get a good {}", somePropertyFile.get( "drink" ) );

    }

    @Bean(name = "my.properties")
    public Properties getSomeProperties() throws Exception{
        Properties properties = new Properties( );
        try(InputStream inputStream = Thread.currentThread().getContextClassLoader().getResourceAsStream( "my.properties" ))
        {
            properties.load( inputStream );
        }
        return properties;
    }

}

==> jetty9_9.4.26.orig.tar.xz: jetty9-9.4.26/jetty-maven-plugin/src/it/javax-annotation-api/src/main/java/test/App.java <==
//
//  ========================================================================
//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
//  ------------------------------------------------------------------------
//  All rights reserved. This program and the accompanying materials
//  are made available under the terms of the Eclipse Public License v1.0
//  and Apache License v2.0 which accompanies this distribution.
//
//      The Eclipse Public License is available at
//      http://www.eclipse.org/legal/epl-v10.html
//
//      The Apache License v2.0 is available at
//      http://www.opensource.org/licenses/apache2.0.php
//
//  You may elect to redistribute this code under either of these licenses.
//  ========================================================================
//

package test;

import java.io.InputStream;
import java.util.Properties;
import javax.annotation.PostConstruct;
import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.builder.SpringApplicationBuilder;
import org.springframework.boot.web.servlet.support.SpringBootServletInitializer;
import org.springframework.context.annotation.Bean;

/**
 * Hello world!
 */
public class App extends SpringBootServletInitializer
{

    private Logger logger = LoggerFactory.getLogger(getClass());

    @Resource(name = "my.properties")
    private Properties somePropertyFile;

    @Override
    protected SpringApplicationBuilder configure(SpringApplicationBuilder builder)
    {
        return builder.sources(App.class);
    }

    @PostConstruct
    public void done()
    {
        logger.info("all good guys get a good {}", somePropertyFile.get("drink"));
    }

    @Bean(name = "my.properties")
    public Properties getSomeProperties() throws Exception
    {
        Properties properties = new Properties();
        try (InputStream inputStream = Thread.currentThread().getContextClassLoader().getResourceAsStream("my.properties"))
        {
            properties.load(inputStream);
        }
        return properties;
    }
}
